==> jc-1.4.0.tar.gz: soot/xml/ColorAttribute.h <==
// public class soot.xml.ColorAttribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 438f1996267200b8 soot_xml_ColorAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_ColorAttribute_H_
#define _JC_soot_xml_ColorAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_xml_ColorAttribute$sub_refs	_jc_soot_xml_ColorAttribute$sub_refs;
typedef struct _jc_soot_xml_ColorAttribute$sub_nonrefs	_jc_soot_xml_ColorAttribute$sub_nonrefs;
typedef struct _jc_soot_xml_ColorAttribute$refs	_jc_soot_xml_ColorAttribute$refs;
typedef struct _jc_soot_xml_ColorAttribute$nonrefs	_jc_soot_xml_ColorAttribute$nonrefs;
typedef struct _jc_soot_xml_ColorAttribute$object	_jc_soot_xml_ColorAttribute$object;

typedef const struct _jc_soot_xml_ColorAttribute$vmethods	_jc_soot_xml_ColorAttribute$vmethods;
typedef const struct _jc_soot_xml_ColorAttribute$vtable	_jc_soot_xml_ColorAttribute$vtable;
typedef const struct _jc_soot_xml_ColorAttribute$vtype	_jc_soot_xml_ColorAttribute$vtype;

// Constructors
extern void _jc_soot_xml_ColorAttribute$method$_init$326022f9a36582e9(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *, jint, jint, jint, jboolean);

// Virtual methods
extern jint _jc_soot_xml_ColorAttribute$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
extern jint _jc_soot_xml_ColorAttribute$method$fg$8bb01f657806c2c1(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
extern jint _jc_soot_xml_ColorAttribute$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
extern jint _jc_soot_xml_ColorAttribute$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$fg$8bb01f657806c2c1;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_xml_ColorAttribute$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
	jint	(*fg$8bb01f657806c2c1)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *);
};

// Vtable
struct _jc_soot_xml_ColorAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_ColorAttribute$vmethods	soot_xml_ColorAttribute;
};

// Vtype
struct _jc_soot_xml_ColorAttribute$vtype {
	_jc_type			type;
	_jc_soot_xml_ColorAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_ColorAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_xml_ColorAttribute$refs {
    _jc_soot_xml_ColorAttribute$sub_refs	soot_xml_ColorAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_ColorAttribute$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
	jint	fg;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_ColorAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_ColorAttribute$sub_nonrefs	soot_xml_ColorAttribute;
};

// Object instance structure
struct _jc_soot_xml_ColorAttribute$object {
	_jc_soot_xml_ColorAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_ColorAttribute$vtype	*vtype;
	_jc_soot_xml_ColorAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_ColorAttribute$vtype _jc_soot_xml_ColorAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_ColorAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_ColorAttribute$class_object;

#endif	/* _JC_soot_xml_ColorAttribute_H_ */

==> jc-1.4.6.tar.gz: soot/xml/ColorAttribute.h <==
// public class soot.xml.ColorAttribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 438f1996267200b8 soot_xml_ColorAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_xml_ColorAttribute_H_
#define _JC_soot_xml_ColorAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_xml_ColorAttribute$sub_refs	_jc_soot_xml_ColorAttribute$sub_refs;
typedef struct _jc_soot_xml_ColorAttribute$sub_nonrefs	_jc_soot_xml_ColorAttribute$sub_nonrefs;
typedef struct _jc_soot_xml_ColorAttribute$refs	_jc_soot_xml_ColorAttribute$refs;
typedef struct _jc_soot_xml_ColorAttribute$nonrefs	_jc_soot_xml_ColorAttribute$nonrefs;
typedef struct _jc_soot_xml_ColorAttribute$object	_jc_soot_xml_ColorAttribute$object;

typedef const struct _jc_soot_xml_ColorAttribute$vmethods	_jc_soot_xml_ColorAttribute$vmethods;
typedef const struct _jc_soot_xml_ColorAttribute$vtable	_jc_soot_xml_ColorAttribute$vtable;
typedef const struct _jc_soot_xml_ColorAttribute$vtype	_jc_soot_xml_ColorAttribute$vtype;

// Constructors
extern void _jc_soot_xml_ColorAttribute$method$_init$326022f9a36582e9(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *, jint, jint, jint, jboolean) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_xml_ColorAttribute$method$blue$b7dee708615eaa32(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_ColorAttribute$method$fg$8bb01f657806c2c1(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_ColorAttribute$method$green$53ef4b741280a296(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_xml_ColorAttribute$method$red$7d0da69269fa97dd(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$blue$b7dee708615eaa32;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$fg$8bb01f657806c2c1;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$green$53ef4b741280a296;
extern _jc_method _jc_soot_xml_ColorAttribute$method_info$red$7d0da69269fa97dd;

// Virtual methods structure
struct _jc_soot_xml_ColorAttribute$vmethods {
	jint	(*blue$b7dee708615eaa32)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
	jint	(*fg$8bb01f657806c2c1)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
	jint	(*green$53ef4b741280a296)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
	jint	(*red$7d0da69269fa97dd)(_jc_env *, struct _jc_soot_xml_ColorAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_xml_ColorAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_xml_ColorAttribute$vmethods	soot_xml_ColorAttribute;
};

// Vtype
struct _jc_soot_xml_ColorAttribute$vtype {
	_jc_type			type;
	_jc_soot_xml_ColorAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_xml_ColorAttribute$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_xml_ColorAttribute$refs {
    _jc_soot_xml_ColorAttribute$sub_refs	soot_xml_ColorAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_xml_ColorAttribute$sub_nonrefs {
	jint	red;
	jint	green;
	jint	blue;
	jint	fg;
};

// Non-reference instance fields (object)
struct _jc_soot_xml_ColorAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_xml_ColorAttribute$sub_nonrefs	soot_xml_ColorAttribute;
};

// Object instance structure
struct _jc_soot_xml_ColorAttribute$object {
	_jc_soot_xml_ColorAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_xml_ColorAttribute$vtype	*vtype;
	_jc_soot_xml_ColorAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_xml_ColorAttribute$vtype _jc_soot_xml_ColorAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_xml_ColorAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_xml_ColorAttribute$class_object;

#endif	/* _JC_soot_xml_ColorAttribute_H_ */
